@@ -36,6 +36,7 @@ class SnapBackend : public AbstractResourcesBackend
 Q_OBJECT
 public:
     explicit SnapBackend(QObject* parent = nullptr);
+    ~SnapBackend() override;
 
     ResultsStream * search(const AbstractResourcesBackend::Filters & search) override;
     ResultsStream * findResourceByPackageName(const QUrl& search);
@@ -66,7 +67,7 @@ private:
 
     QHash<QString, SnapResource*> m_resources;
     StandardBackendUpdater* m_updater;
-    OdrsReviewsBackend* m_reviews;
+    QSharedPointer<OdrsReviewsBackend> m_reviews;
 
     bool m_valid = true;
     bool m_fetching = false;
