@@ -21,16 +21,15 @@
 #ifndef ABSTRACTRESOURCESBACKEND_H
 #define ABSTRACTRESOURCESBACKEND_H
 
-#include <QtCore/QObject>
-#include <QtCore/QPair>
-#include <QtCore/QVector>
+#include <QObject>
+#include <QPair>
+#include <QVector>
 
 #include "AbstractResource.h"
 #include "Transaction/AddonList.h"
 
 #include "discovercommon_export.h"
 
-class QAction;
 class Transaction;
 class Category;
 class AbstractReviewsBackend;
@@ -50,6 +49,7 @@ class DISCOVERCOMMON_EXPORT ResultsStream : public QObject
 
     Q_SIGNALS:
         void resourcesFound(const QVector<AbstractResource*>& resources);
+        void fetchMore();
 };
 
 /**
@@ -67,7 +67,7 @@ class DISCOVERCOMMON_EXPORT ResultsStream : public QObject
  * To show resources in Muon, we need to initialize all resources we want to show beforehand,
  * we should not create resources in the search function. When we reload the resources
  * (e.g. when initializing), the backend needs change the fetching property throughout the
- * processs.
+ * process.
  */
 class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
 {
@@ -76,7 +76,9 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
     Q_PROPERTY(QString displayName READ displayName CONSTANT)
     Q_PROPERTY(AbstractReviewsBackend* reviewsBackend READ reviewsBackend CONSTANT)
     Q_PROPERTY(int updatesCount READ updatesCount NOTIFY updatesCountChanged)
+    Q_PROPERTY(bool hasSecurityUpdates READ hasSecurityUpdates NOTIFY updatesCountChanged)
     Q_PROPERTY(bool isFetching READ isFetching NOTIFY fetchingChanged)
+    Q_PROPERTY(bool hasApplications READ hasApplications CONSTANT)
     public:
         /**
          * Constructs an AbstractResourcesBackend
@@ -97,8 +99,11 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
             QString search;
             QString extends;
             QUrl resourceUrl;
-            QHash<QByteArray, QVariant> roles;
+            QString origin;
             bool allBackends = false;
+            bool filterMinimumState = true;
+
+            bool isEmpty() const { return !category && state == AbstractResource::Broken && mimetype.isEmpty() && search.isEmpty() && extends.isEmpty() && resourceUrl.isEmpty() && origin.isEmpty(); }
 
             bool shouldFilter(AbstractResource* res) const;
             void filterJustInCase(QVector<AbstractResource*>& input) const;
@@ -110,8 +115,6 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
 
         virtual ResultsStream* search(const Filters &search) = 0;//FIXME: Probably provide a standard implementation?!
 
-        virtual ResultsStream* findResourceByPackageName(const QUrl &search) = 0;//FIXME: Probably provide a standard implementation?!
-        
         /**
          * @returns the reviews backend of this AbstractResourcesBackend (which handles all ratings and reviews of resources)
          */
@@ -128,20 +131,16 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
          */
         virtual int updatesCount() const = 0;//FIXME: Probably provide a standard implementation?!
 
+        /**
+         * @returns whether either of the updates contains a security fix
+         */
+        virtual bool hasSecurityUpdates() const { return false; }
+
         /**
          * Tells whether the backend is fetching resources
          */
         virtual bool isFetching() const = 0;
 
-        /**
-         *  This method is used to integrate advanced functions into the Muon GUI.
-         *
-         *  In plasma-discover-updater, actions with HighPriority will be shown in a KMessageWidget,
-         *  normal priority will go right on top of the more menu, low priority will go
-         *  to the advanced menu.
-         */
-        virtual QList<QAction*> messageActions() const = 0;
-
         /**
          * @returns the appstream ids that this backend extends
          */
@@ -160,8 +159,6 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
          */
         void emitRatingsReady();
 
-        virtual AbstractResource* resourceForFile(const QUrl &/*url*/) { return nullptr; }
-
         /**
          * @returns the root category tree
          */
@@ -229,17 +226,6 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
         QString m_name;
 };
 
-template <typename T, typename W>
-static T containerValues(const W& container)
-{
-    T ret;
-    ret.reserve(container.size());
-    for(auto a : container) {
-        ret.push_back(a);
-    }
-    return ret;
-}
-
 DISCOVERCOMMON_EXPORT QDebug operator<<(QDebug dbg, const AbstractResourcesBackend::Filters& filters);
 
 /**
@@ -252,7 +238,7 @@ public:
     virtual QVector<AbstractResourcesBackend*> newInstance(QObject* parent, const QString &name) const = 0;
 };
 
-#define MUON_BACKEND_PLUGIN(ClassName)\
+#define DISCOVER_BACKEND_PLUGIN(ClassName)\
     class ClassName##Factory : public AbstractResourcesBackendFactory {\
         Q_OBJECT\
         Q_PLUGIN_METADATA(IID "org.kde.muon.AbstractResourcesBackendFactory")\
